==> micro-website-mall-core-1.0.0-sources.jar: com/ptteng/sca/micro/mall/client/PropertyItemSCAClient.java <==
/**
 * 
 */
package com.ptteng.sca.micro.mall.client;

import java.util.List;
import java.util.Map;

import com.ptteng.micro.mall.model.PropertyItem;
import com.ptteng.micro.mall.service.PropertyItemService;
import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;

public class PropertyItemSCAClient implements PropertyItemService {

    private PropertyItemService propertyItemService;

	public PropertyItemService getPropertyItemService() {
		return propertyItemService;
	}
	
	
	public void setPropertyItemService(PropertyItemService propertyItemService) {
		this.propertyItemService =propertyItemService;
	}
	
	
			   
		@Override
		public Long insert(PropertyItem propertyItem)throws ServiceException, ServiceDaoException{
		
		return propertyItemService.insert(propertyItem);
		          
		
		}	
		  
    	   
		@Override
		public List<PropertyItem> insertList(List<PropertyItem> propertyItemList)throws ServiceException, ServiceDaoException{
		
		return propertyItemService.insertList(propertyItemList);
		          
		
		}	
		  
    	   
		@Override
		public boolean delete(Long id)throws ServiceException, ServiceDaoException{
		
		return propertyItemService.delete(id);
		          
		
		}	
		  
    	   
		@Override
		public boolean update(PropertyItem propertyItem)throws ServiceException, ServiceDaoException{
		
		return propertyItemService.update(propertyItem);
		          
		
		}	
		  
    	   
		@Override
		public boolean updateList(List<PropertyItem> propertyItemList)throws ServiceException, ServiceDaoException{
		
		return propertyItemService.updateList(propertyItemList);
		          
		
		}	
		  
    	   
		@Override
		public PropertyItem getObjectById(Long id)throws ServiceException, ServiceDaoException{
		
		return propertyItemService.getObjectById(id);
		          
		
		}	
		  
    	   
		@Override
		public List<PropertyItem> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException{
		
		return propertyItemService.getObjectsByIds(ids);
		          
		
		}	
		  
    	
	
	
	
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getPropertyItemIdsByPropertyIdAndStatusAndTitle(Long propertyId,Integer status,String title,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return propertyItemService.getPropertyItemIdsByPropertyIdAndStatusAndTitle(propertyId,status,title,start,limit);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getPropertyItemIdsByPropertyIdAndStatus(Long propertyId,Integer status,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return propertyItemService.getPropertyItemIdsByPropertyIdAndStatus(propertyId,status,start,limit);
	
	
	}
	
		
	
	
    			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countPropertyItemIdsByPropertyIdAndStatusAndTitle(Long propertyId,Integer status,String title)throws ServiceException, ServiceDaoException{
		
		return propertyItemService.countPropertyItemIdsByPropertyIdAndStatusAndTitle(propertyId,status,title);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countPropertyItemIdsByPropertyIdAndStatus(Long propertyId,Integer status)throws ServiceException, ServiceDaoException{
		
		return propertyItemService.countPropertyItemIdsByPropertyIdAndStatus(propertyId,status);
	
	
	}
	
		
	
		@Override
	public List<Long> getPropertyItemIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return propertyItemService.getPropertyItemIds(start, limit);
	}

	@Override
	public Integer countPropertyItemIds() throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return propertyItemService.countPropertyItemIds();
	}
	
	
	@Override
	public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return propertyItemService.getIdsByDynamicCondition(clz, conditions, start, limit);
	}


	@Override
	public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return propertyItemService.fakeDelete(clz, id);
	}
	
	
	
	@Override
	public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
		   propertyItemService.deleteList(clz, ids);
		
	}
	
	@Override
	public Object getObjectByDynamicCondition(Class clz,
			Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
	
		return this.propertyItemService.getObjectByDynamicCondition(clz, conditions, start, limit);
	}


 
}

==> micro-website-mall-core-1.1.7.1-sources.jar: com/ptteng/sca/micro/mall/client/PropertyItemSCAClient.java <==
/**
 * 
 */
package com.ptteng.sca.micro.mall.client;

import java.util.List;
import java.util.Map;

import com.ptteng.micro.mall.model.PropertyItem;
import com.ptteng.micro.mall.service.PropertyItemService;
import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;

public class PropertyItemSCAClient implements PropertyItemService {

    private PropertyItemService propertyItemService;

	public PropertyItemService getPropertyItemService() {
		return propertyItemService;
	}
	
	
	public void setPropertyItemService(PropertyItemService propertyItemService) {
		this.propertyItemService =propertyItemService;
	}
	
	
			   
		@Override
		public Long insert(PropertyItem propertyItem)throws ServiceException, ServiceDaoException{
		
		return propertyItemService.insert(propertyItem);
		          
		
		}	
		  
    	   
		@Override
		public List<PropertyItem> insertList(List<PropertyItem> propertyItemList)throws ServiceException, ServiceDaoException{
		
		return propertyItemService.insertList(propertyItemList);
		          
		
		}	
		  
    	   
		@Override
		public boolean delete(Long id)throws ServiceException, ServiceDaoException{
		
		return propertyItemService.delete(id);
		          
		
		}	
		  
    	   
		@Override
		public boolean update(PropertyItem propertyItem)throws ServiceException, ServiceDaoException{
		
		return propertyItemService.update(propertyItem);
		          
		
		}	
		  
    	   
		@Override
		public boolean updateList(List<PropertyItem> propertyItemList)throws ServiceException, ServiceDaoException{
		
		return propertyItemService.updateList(propertyItemList);
		          
		
		}	
		  
    	   
		@Override
		public PropertyItem getObjectById(Long id)throws ServiceException, ServiceDaoException{
		
		return propertyItemService.getObjectById(id);
		          
		
		}	
		  
    	   
		@Override
		public List<PropertyItem> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException{
		
		return propertyItemService.getObjectsByIds(ids);
		          
		
		}	
		  
    	
	
	
	
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getPropertyItemIdsByPropertyIdAndStatusAndTitle(Long propertyId,Integer status,String title,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return propertyItemService.getPropertyItemIdsByPropertyIdAndStatusAndTitle(propertyId,status,title,start,limit);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getPropertyItemIdsByPropertyIdAndStatus(Long propertyId,Integer status,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return propertyItemService.getPropertyItemIdsByPropertyIdAndStatus(propertyId,status,start,limit);
	
	
	}
	
		
	
	
    			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countPropertyItemIdsByPropertyIdAndStatusAndTitle(Long propertyId,Integer status,String title)throws ServiceException, ServiceDaoException{
		
		return propertyItemService.countPropertyItemIdsByPropertyIdAndStatusAndTitle(propertyId,status,title);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countPropertyItemIdsByPropertyIdAndStatus(Long propertyId,Integer status)throws ServiceException, ServiceDaoException{
		
		return propertyItemService.countPropertyItemIdsByPropertyIdAndStatus(propertyId,status);
	
	
	}
	
		
	
		@Override
	public List<Long> getPropertyItemIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return propertyItemService.getPropertyItemIds(start, limit);
	}

	@Override
	public Integer countPropertyItemIds() throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return propertyItemService.countPropertyItemIds();
	}
	
	
	@Override
	public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return propertyItemService.getIdsByDynamicCondition(clz, conditions, start, limit);
	}


	@Override
	public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return propertyItemService.fakeDelete(clz, id);
	}
	
	
	
	@Override
	public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
		   propertyItemService.deleteList(clz, ids);
		
	}
	
	@Override
	public Object getObjectByDynamicCondition(Class clz,
			Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
	
		return this.propertyItemService.getObjectByDynamicCondition(clz, conditions, start, limit);
	}

	@Override
	public Object getMapListByDynamicCondition(Class clz,
											   Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {

		return this.propertyItemService.getMapListByDynamicCondition(clz, conditions, start, limit);
	}

 
}
